==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/metrics/metric/DefaultHttpSocketMetric.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.vertx.metrics.metric;

public class DefaultHttpSocketMetric extends DefaultTcpSocketMetric {
  private long requestBeginTime;

  private long requestEndTime;

  public DefaultHttpSocketMetric() {
  }

  public DefaultHttpSocketMetric(DefaultEndpointMetric endpointMetric) {
    super(endpointMetric);
  }

  public long getRequestBeginTime() {
    return requestBeginTime != 0 ? requestBeginTime : System.nanoTime();
  }

  public void requestBegin() {
    this.requestBeginTime = System.nanoTime();
  }

  public long getRequestEndTime() {
    return requestEndTime != 0 ? requestEndTime : System.nanoTime();
  }

  public void requestEnd() {
    this.requestEndTime = System.nanoTime();
  }
}

==> apache-servicecomb-java-chassis-distribution-2.1.5-src.zip: apache-servicecomb-java-chassis-distribution-2.1.5-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/metrics/metric/DefaultHttpSocketMetric.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.vertx.metrics.metric;

// if can not get connection from connection pool
// then both requestBeginTime and requestEndTime will be 0
public class DefaultHttpSocketMetric extends DefaultTcpSocketMetric {
  private long requestBeginTime;

  private long requestEndTime;

  public DefaultHttpSocketMetric() {
  }

  public DefaultHttpSocketMetric(DefaultEndpointMetric endpointMetric) {
    super(endpointMetric);
  }

  public long getRequestBeginTime() {
    return requestBeginTime != 0 ? requestBeginTime : System.nanoTime();
  }

  public void requestBegin() {
    this.requestBeginTime = System.nanoTime();
  }

  public long getRequestEndTime() {
    return requestEndTime != 0 ? requestEndTime : System.nanoTime();
  }

  public void requestEnd() {
    this.requestEndTime = System.nanoTime();
  }
}
